/// <reference types="ioredis" />
import { Redis } from 'ioredis';
import { Field } from './field';
import { Query } from './query';
import { Result } from './result';
export interface SchemaDictionary {
    [key: string]: any;
}
export interface NumericDictionary {
    [key: string]: number;
}
export declare type SearchDictionary = NumericDictionary;
export declare type SnippetsDictionary = NumericDictionary;
export declare class Client<C extends Redis> {
    private indexName;
    private redis;
    constructor(indexName: string, conn: C);
    /**
     * createIndex
     */
    createIndex(fields: Field[]): Promise<'OK'>;
    /**
     * dropIndex
     */
    dropIndex(): Promise<'OK'>;
    /**
     * addDocument
     */
    addDocument<T extends SchemaDictionary>(docId: string, fields: T, score?: number, payload?: Object, noSave?: boolean, replace?: boolean, partial?: boolean): Promise<'OK'>;
    /**
     * Search the index for a given query, and return a result of documents
     * @param queryOrString the search query.
     * Either a text for simple queries
     * with default parameters,
     * or a Query object for complex queries.
     * See RediSearch's documentation on query format
     * @param snippetSizes A dictionary of {field: snippet_size}
     * used to trim and format the result. e.g. {'body': 500}
     */
    search<T = SchemaDictionary, S = NumericDictionary>(queryOrString: Query | string, snippetSizes?: S): Promise<Result<T, S>>;
    private _addDocument<T>(conn, docId, fields, score?, payload?, noSave?, replace?, partial?);
    private toQuery(query);
}
